@@ -7,11 +7,11 @@
 #ifndef BRKPT_H
 #define BRKPT_H
 
-#include <qlistview.h>
-#include <qlayout.h>
-#include <qpushbutton.h>
-#include <qlineedit.h>
-#include <qvaluevector.h>
+#include <QIcon>
+#include <QEvent>
+#include <vector>
+
+#include "ui_brkptbase.h"
 
 class KDebugger;
 class BreakpointItem;
@@ -21,24 +21,14 @@ class BreakpointTable : public QWidget
 {
     Q_OBJECT
 public:
-    BreakpointTable(QWidget* parent, const char* name);
+    BreakpointTable(QWidget* parent);
     ~BreakpointTable();
     void setDebugger(KDebugger* deb) { m_debugger = deb; }
 
 protected:
     KDebugger* m_debugger;
-    QLineEdit m_bpEdit;
-    QListView m_list;
-    QPushButton m_btAddBP;
-    QPushButton m_btAddWP;
-    QPushButton m_btRemove;
-    QPushButton m_btEnaDis;
-    QPushButton m_btViewCode;
-    QPushButton m_btConditional;
-    QHBoxLayout m_layout;
-    QVBoxLayout m_listandedit;
-    QVBoxLayout m_buttons;
-    QValueVector<QPixmap> m_icons;
+    Ui::BrkPtBase m_ui;
+    std::vector<QIcon> m_icons;
 
     void insertBreakpoint(int num, bool temp, bool enabled, QString location,
 			  QString fileName = 0, int lineNo = -1,
@@ -62,12 +52,12 @@ signals:
      */
     void activateFileLine(const QString& file, int lineNo, const DbgAddr& address);
 public slots:
-    virtual void addBP();
-    virtual void addWP();
-    virtual void removeBP();
-    virtual void enadisBP();
-    virtual void viewBP();
-    virtual void conditionalBP();
+    void on_btAddBP_clicked();
+    void on_btAddWP_clicked();
+    void on_btRemove_clicked();
+    void on_btEnaDis_clicked();
+    void on_btViewCode_clicked();
+    void on_btConditional_clicked();
     void updateUI();
     void updateBreakList();
 };
