@@ -9,7 +9,5 @@
 
 // statusbar ids
 #define ID_STATUS_MSG 191
-#define ID_STATUS_BUSY 192
 #define ID_STATUS_ACTIVE 193
-#define ID_STATUS_LINENO 194
 #endif // COMMANDIDS_H
