@@ -7,10 +7,9 @@
 #ifndef DBGDRIVER_H
 #define DBGDRIVER_H
 
-#include <qfile.h>
-#include <qregexp.h>
-#include <qcstring.h>
-#include <kprocess.h>
+#include <QFile>
+#include <QByteArray>
+#include <QProcess>
 #include <queue>
 #include <list>
 
@@ -150,6 +149,7 @@ struct CmdQueueItem
     // remember file position
     QString m_fileName;
     int m_lineNo;
+    DbgAddr m_addr;
     // the breakpoint info
     Breakpoint* m_brkpt;
     int m_existingBrkpt;
@@ -270,7 +270,7 @@ struct MemoryDump
  * interface to the commandline debugger. As such it implements the
  * commands and parses the output.
  */
-class DebuggerDriver : public KProcess
+class DebuggerDriver : public QProcess
 {
     Q_OBJECT
 public:
@@ -290,6 +290,7 @@ public:
 
     virtual bool startup(QString cmdStr);
     void setLogFileName(const QString& fname) { m_logFileName = fname; }
+    bool isRunning() { return state() != NotRunning; }
 
 protected:
     QString m_runCmd;
@@ -312,11 +313,8 @@ public:
     bool canExecuteImmediately() const { return m_hipriCmdQueue.empty(); }
 
 protected:
-    char* m_output;			/* normal gdb output */
-    size_t m_outputLen;			/* amount of data so far accumulated in m_output */
-    size_t m_outputAlloc;		/* space available in m_output */
-    std::queue<QByteArray> m_delayedOutput;	/* output colleced while we have receivedOutput */
-					/* but before signal wroteStdin arrived */
+    QByteArray m_output;		// normal gdb output
+    std::queue<QByteArray> m_delayedOutput;	// output colleced before signal bytesWritten() arrived
 
 public:
     /**
@@ -562,13 +560,14 @@ protected:
     virtual void commandFinished(CmdQueueItem* cmd) = 0;
 
 protected:
-    /** @internal */
-    virtual int commSetupDoneC();
+    void processOutput(const QByteArray& data);
 
-    char m_prompt[10];
-    size_t m_promptMinLen;
-    char m_promptLastChar;
-    QRegExp m_promptRE;
+    /**
+     * Returns the start of the prompt in \a output or -1.
+     * \a len specifies the size of \a output, but in addition, the contents
+     * of \a output are NUL-terminated, i.e., \c output[len] is zero.
+     */
+    virtual int findPrompt(const QByteArray& output) const = 0;
 
     // log file
     QString m_logFileName;
@@ -578,9 +577,9 @@ public slots:
     void dequeueCmdByVar(VarTree* var);
 
 protected slots:
-    virtual void slotReceiveOutput(KProcess*, char* buffer, int buflen);
-    virtual void slotCommandRead(KProcess*);
-    virtual void slotExited(KProcess*);
+    virtual void slotReceiveOutput();
+    virtual void slotCommandRead();
+    virtual void slotExited();
     
 signals:
     /**
