@@ -9,16 +9,16 @@
 
 /*
  * Description of environment variables. Note that the name of the variable
- * is given as the key in the QDict, so we don't repeat it here.
+ * is given as the key in the map, so we don't repeat it here.
  */
 
-class QListViewItem;
+class QTreeWidgetItem;
 
 struct EnvVar {
     QString value;
     enum EnvVarStatus { EVclean, EVdirty, EVnew, EVdeleted };
     EnvVarStatus status;
-    QListViewItem* item;
+    QTreeWidgetItem* item;
 };
 
 #endif // ENVVAR_H
