@@ -7,11 +7,11 @@
 #ifndef MEMWINDOW_H
 #define MEMWINDOW_H
 
-#include <qpopupmenu.h>
-#include <qlistview.h>
-#include <qcombobox.h>
-#include <qlayout.h>
-#include <qmap.h>
+#include <QBoxLayout>
+#include <QComboBox>
+#include <QMap>
+#include <QMenu>
+#include <QTreeWidget>
 #include "dbgdriver.h"
 
 class KDebugger;
@@ -21,7 +21,7 @@ class MemoryWindow : public QWidget
 {
     Q_OBJECT
 public:
-    MemoryWindow(QWidget* parent, const char* name);
+    MemoryWindow(QWidget* parent);
     ~MemoryWindow();
 
     void setDebugger(KDebugger* deb) { m_debugger = deb; }
@@ -30,23 +30,23 @@ protected:
     KDebugger* m_debugger;
     QComboBox m_expression;
 
-    QListView m_memory;
+    QTreeWidget m_memory;
     QMap<QString,QString> m_old_memory;
 
-    QVBoxLayout m_layout;
+    QBoxLayout m_layout;
 
     unsigned m_format;
     QMap<QString,unsigned> m_formatCache;
 
-    QPopupMenu m_popup;
+    QMenu m_popup;
 
-    virtual bool eventFilter(QObject* o, QEvent* ev);
-    void handlePopup(QMouseEvent* ev);
+    virtual void contextMenuEvent(QContextMenuEvent* ev);
     void displayNewExpression(const QString& expr);
 
 public slots:
     void slotNewExpression(const QString&);
-    void slotTypeChange(int id);
+    void slotNewExpression();
+    void slotTypeChange(QAction*);
     void slotNewMemoryDump(const QString&, const std::list<MemoryDump>&);
     void saveProgramSpecific(KConfigBase* config);
     void restoreProgramSpecific(KConfigBase* config);
