@@ -6,20 +6,20 @@
 
 #include <kdebug.h>
 #include <assert.h>
+#include "config.h"
 
 #ifdef ASSERT
 #undef ASSERT
 #endif
 
 #ifdef NDEBUG
-# define ASSERT(x) ((void)0)
+# define ASSERT(x) do {} while (0)
 #else
-# define ASSERT(x) ((x) ? void(0) : void(kdDebug() << \
-					(QString("assertion failed: ") + #x).ascii() << "\n"))
+# define ASSERT(x) kDebug(!(x)) << "assertion failed: " #x "\n"
 #endif
 
 #ifdef WANT_TRACE_OUTPUT
-# define TRACE(x) (kdDebug() << (const char*)(x) << "\n")
+# define TRACE(x) kDebug() << (x)
 #else
-# define TRACE(x) ((void)0)
+# define TRACE(x) do {} while (0)
 #endif
