@@ -7,45 +7,45 @@
 #ifndef PgmArgs_included
 #define PgmArgs_included
 
-#include "pgmargsbase.h"
-#include <qlineedit.h>
-#include <qdict.h>
+#include "ui_pgmargsbase.h"
+#include <QDialog>
+#include <QSet>
+#include <map>
 #include "envvar.h"
 
 class QStringList;
 
-class PgmArgs : public PgmArgsBase
+class PgmArgs : public QDialog, private Ui::PgmArgsBase
 {
     Q_OBJECT
 public:
-    PgmArgs(QWidget* parent, const QString& pgm, QDict<EnvVar>& envVars,
+    PgmArgs(QWidget* parent, const QString& pgm,
+	    const std::map<QString,QString>& envVars,
 	    const QStringList& allOptions);
     virtual ~PgmArgs();
 
     void setArgs(const QString& text) { programArgs->setText(text); }
     QString args() const { return programArgs->text(); }
-    void setOptions(const QStringList& selectedOptions);
-    QStringList options() const;
+    void setOptions(const QSet<QString>& selectedOptions);
+    QSet<QString> options() const;
     void setWd(const QString& wd) { wdEdit->setText(wd); }
     QString wd() const { return wdEdit->text(); }
-    QDict<EnvVar>& envVars() { return m_envVars; }
+    const std::map<QString,EnvVar>& envVars() { return m_envVars; }
 
 protected:
-    QDict<EnvVar> m_envVars;
+    std::map<QString,EnvVar> m_envVars;
 
-    void initEnvList();
     void parseEnvInput(QString& name, QString& value);
     void modifyVar(bool resurrect);
+    virtual void accept();
 
 protected slots:
-    void modifyVar();
-    void deleteVar();
-    void envListCurrentChanged();
-    void accept();
-    void browseWd();
-    void browseArgFile();
-    void browseArgDir();
-    void invokeHelp();
+    void on_buttonModify_clicked();
+    void on_buttonDelete_clicked();
+    void on_envList_currentItemChanged();
+    void on_wdBrowse_clicked();
+    void on_insertFile_clicked();
+    void on_insertDir_clicked();
 };
 
 #endif // PgmArgs_included
