@@ -7,9 +7,9 @@
 #ifndef PREFDEBUGGER_H
 #define PREFDEBUGGER_H
 
-#include <qlayout.h>
-#include <qlineedit.h>
-#include <qlabel.h>
+#include <QLineEdit>
+#include <QLabel>
+#include <QGridLayout>
 
 class PrefDebugger : public QWidget
 {
