@@ -7,10 +7,10 @@
 #ifndef PREFMISC_H
 #define PREFMISC_H
 
-#include <qlayout.h>
-#include <qcheckbox.h>
-#include <qlabel.h>
-#include <qlineedit.h>
+#include <QCheckBox>
+#include <QLabel>
+#include <QLineEdit>
+#include <QGridLayout>
 
 class PrefMisc : public QWidget
 {
