@@ -8,22 +8,23 @@
 #include "dbgdriver.h"
 #include <klocale.h>
 #include <kiconloader.h>
-#include <qbitmap.h>
-#include <qpainter.h>
+#include <QBitmap>
+#include <QHeaderView>
+#include <QPainter>
 
 
-class ThreadEntry : public QListViewItem, public ThreadInfo
+class ThreadEntry : public QTreeWidgetItem, public ThreadInfo
 {
 public:
-    ThreadEntry(QListView* parent, ThreadInfo* thread);
+    ThreadEntry(QTreeWidget* parent, const ThreadInfo& thread);
     void setFunction(const QString& func);
 
     bool m_delete;			/* used for updating the list */
 };
 
-ThreadEntry::ThreadEntry(QListView* parent, ThreadInfo* thread) :
-	QListViewItem(parent, thread->threadName, thread->function),
-	ThreadInfo(*thread),
+ThreadEntry::ThreadEntry(QTreeWidget* parent, const ThreadInfo& thread) :
+	QTreeWidgetItem(parent, QStringList() << thread.threadName << thread.function),
+	ThreadInfo(thread),
 	m_delete(false)
 {
 }
@@ -35,49 +36,51 @@ void ThreadEntry::setFunction(const QString& func)
 }
 
 
-ThreadList::ThreadList(QWidget* parent, const char* name) :
-	QListView(parent, name)
+ThreadList::ThreadList(QWidget* parent) :
+	QTreeWidget(parent)
 {
-    addColumn(i18n("Thread ID"), 150);
-    addColumn(i18n("Location"));
+    setHeaderLabels(QStringList() << i18n("Thread ID") << i18n("Location"));
+    header()->setResizeMode(1, QHeaderView::Interactive);
+    setRootIsDecorated(false);
 
     // load pixmaps
     m_focusIcon = UserIcon("pcinner");
     makeNoFocusIcon();
 
-    connect(this, SIGNAL(currentChanged(QListViewItem*)),
-	    this, SLOT(slotCurrentChanged(QListViewItem*)));
+    connect(this, SIGNAL(currentItemChanged(QTreeWidgetItem*, QTreeWidgetItem*)),
+	    this, SLOT(slotCurrentChanged(QTreeWidgetItem*)));
 }
 
 ThreadList::~ThreadList()
 {
 }
 
-void ThreadList::updateThreads(QList<ThreadInfo>& threads)
+void ThreadList::updateThreads(const std::list<ThreadInfo>& threads)
 {
     // reset flag in all items
-    for (QListViewItem* e = firstChild(); e != 0; e = e->nextSibling()) {
-	static_cast<ThreadEntry*>(e)->m_delete = true;
-    }
+    for (QTreeWidgetItemIterator i(this); *i; ++i)
+	static_cast<ThreadEntry*>(*i)->m_delete = true;
 
-    for (ThreadInfo* i = threads.first(); i != 0; i = threads.next()) {
+    for (std::list<ThreadInfo>::const_iterator i = threads.begin(); i != threads.end(); ++i)
+    {
 	// look up this thread by id
 	ThreadEntry* te = threadById(i->id);
 	if (te == 0) {
-	    te = new ThreadEntry(this, i);
+	    te = new ThreadEntry(this, *i);
 	} else {
 	    te->m_delete = false;
 	    te->setFunction(i->function);
 	}
 	// set focus icon
 	te->hasFocus = i->hasFocus;
-	te->setPixmap(0, i->hasFocus  ?  m_focusIcon  :  m_noFocusIcon);
+	te->setIcon(0, i->hasFocus  ?  QIcon(m_focusIcon)  :  QIcon(m_noFocusIcon));
     }
 
     // delete all entries that have not been seen
-    for (QListViewItem* e = firstChild(); e != 0;) {
-	ThreadEntry* te = static_cast<ThreadEntry*>(e);
-	e = e->nextSibling();		/* step ahead before deleting it ;-) */
+    for (QTreeWidgetItemIterator i(this); *i;)
+    {
+	ThreadEntry* te = static_cast<ThreadEntry*>(*i);
+	++i;		// step ahead before deleting it ;-)
 	if (te->m_delete) {
 	    delete te;
 	}
@@ -86,8 +89,9 @@ void ThreadList::updateThreads(QList<ThreadInfo>& threads)
 
 ThreadEntry* ThreadList::threadById(int id)
 {
-    for (QListViewItem* e = firstChild(); e != 0; e = e->nextSibling()) {
-	ThreadEntry* te = static_cast<ThreadEntry*>(e);
+    for (QTreeWidgetItemIterator i(this); *i; ++i)
+    {
+	ThreadEntry* te = static_cast<ThreadEntry*>(*i);
 	if (te->id == id) {
 	    return te;
 	}
@@ -104,12 +108,12 @@ void ThreadList::makeNoFocusIcon()
     m_noFocusIcon = m_focusIcon;
     {
 	QPainter p(&m_noFocusIcon);
-	p.fillRect(0,0, m_noFocusIcon.width(),m_noFocusIcon.height(), QColor(white));
+	p.fillRect(0,0, m_noFocusIcon.width(),m_noFocusIcon.height(), QColor(Qt::white));
     }
     m_noFocusIcon.setMask(m_noFocusIcon.createHeuristicMask());
 }
 
-void ThreadList::slotCurrentChanged(QListViewItem* newItem)
+void ThreadList::slotCurrentChanged(QTreeWidgetItem* newItem)
 {
     if (newItem == 0)
 	return;
